﻿using System;
using System.Data;
using System.Configuration;
using System.Web.UI;
using System.Web.UI.WebControls;
using Telerik.Web.UI;
using System.Linq;
using System.Data.SqlClient;
using Model.ReadWrite.Telerik;

public partial class _Default : System.Web.UI.Page
{
    const int MaxTotalBytes = 1048576; // 1 MB
    Int64 totalBytes;

    private TelerikReadWriteEntities _dataContext;

    protected TelerikReadWriteEntities DbContext
    {
        get
        {
            if (_dataContext == null)
            {
                _dataContext = new TelerikReadWriteEntities();
            }
            return _dataContext;
        }
    }

    public override void Dispose()
    {
        if (_dataContext != null)
        {
            _dataContext.Dispose();
        }
        base.Dispose();
    }

    public bool? IsRadAsyncValid
    {
        get
        {
            if (Session["IsRadAsyncValid"] == null)
            {
                Session["IsRadAsyncValid"] = true;
            }

            return Convert.ToBoolean(Session["IsRadAsyncValid"].ToString());
        }
        set
        {
            Session["IsRadAsyncValid"] = value;
        }
    }

    protected override void OnLoad(EventArgs e)
    {
        base.OnLoad(e);

        IsRadAsyncValid = null;
    }

    protected void RadGrid1_ItemCreated(object sender, GridItemEventArgs e)
    {
        if (e.Item is GridEditableItem && e.Item.IsInEditMode)
        {
            RadAsyncUpload upload = ((GridEditableItem)e.Item)["Upload"].FindControl("AsyncUpload1") as RadAsyncUpload;
            TableCell cell = (TableCell)upload.Parent;

            CustomValidator validator = new CustomValidator();
            validator.ErrorMessage = "Please select file to be uploaded";
            validator.ClientValidationFunction = "validateRadUpload";
            validator.Display = ValidatorDisplay.Dynamic;
            cell.Controls.Add(validator);
        }
    }

    protected string TrimDescription(string description)
    {
        if (!string.IsNullOrEmpty(description) && description.Length > 200)
        {
            return string.Concat(description.Substring(0, 200), "...");
        }
        return description;
    }

    protected void RadGrid1_NeedDataSource(object source, GridNeedDataSourceEventArgs e)
    {
        var result = from r in DbContext.Images
                     select r;
        RadGrid1.DataSource = result;
    }
    protected void RadGrid1_InsertCommand(object source, GridCommandEventArgs e)
    {
        if (!IsRadAsyncValid.Value)
        {
            e.Canceled = true;
            RadAjaxManager1.Alert("The length of the uploaded file must be less than 1 MB");
            return;
        }

        GridEditFormInsertItem insertItem = e.Item as GridEditFormInsertItem;
        string imageName = (insertItem["ImageName"].FindControl("txbName") as RadTextBox).Text;
        string description = (insertItem["Description"].FindControl("txbDescription") as RadTextBox).Text;
        RadAsyncUpload radAsyncUpload = insertItem["Upload"].FindControl("AsyncUpload1") as RadAsyncUpload;

        UploadedFile file = radAsyncUpload.UploadedFiles[0];
        byte[] fileData = new byte[file.InputStream.Length];
        file.InputStream.Read(fileData, 0, (int)file.InputStream.Length);

        //create new entity
        var image = new Model.ReadWrite.Telerik.Image();
        image.Name = imageName;
        image.Description = description;
        image.Data = fileData;

        DbContext.AddToImages(image);
        DbContext.SaveChanges();

    }

    protected void RadGrid1_UpdateCommand(object source, GridCommandEventArgs e)
    {
        if (!IsRadAsyncValid.Value)
        {
            e.Canceled = true;
            RadAjaxManager1.Alert("The length of the uploaded file must be less than 1 MB");
            return;
        }

        GridEditableItem editedItem = e.Item as GridEditableItem;
        int ID = Convert.ToInt32(editedItem.OwnerTableView.DataKeyValues[editedItem.ItemIndex]["ID"].ToString());
        string imageName = (editedItem["ImageName"].FindControl("txbName") as RadTextBox).Text;
        string description = (editedItem["Description"].FindControl("txbDescription") as RadTextBox).Text;
        RadAsyncUpload radAsyncUpload = editedItem["Upload"].FindControl("AsyncUpload1") as RadAsyncUpload;

        //retrive entity form the Db
        var image = DbContext.Images.Where(n => n.ID == ID).FirstOrDefault();

        image.Name = imageName;
        image.Description = description;

        if (radAsyncUpload.UploadedFiles.Count > 0)
        {
            UploadedFile file = radAsyncUpload.UploadedFiles[0];
            byte[] fileData = new byte[file.InputStream.Length];
            file.InputStream.Read(fileData, 0, (int)file.InputStream.Length);


            image.Data = fileData;
        }

        DbContext.SaveChanges();

    }

    protected void RadGrid1_DeleteCommand(object source, GridCommandEventArgs e)
    {
        GridDataItem item = e.Item as GridDataItem;
        int ID = Convert.ToInt32(item.OwnerTableView.DataKeyValues[item.ItemIndex]["ID"].ToString());

        //retrive entity form the Db
        var image = DbContext.Images.Where(n => n.ID == ID).FirstOrDefault();

        if (image != null)
        {
            DbContext.Images.DeleteObject(image);
            DbContext.SaveChanges();
        }
    }

    protected void RadGrid1_ItemCommand(object source, GridCommandEventArgs e)
    {
        if (e.CommandName == RadGrid.EditCommandName)
        {
            ScriptManager.RegisterStartupScript(Page, Page.GetType(), "SetEditMode", "isEditMode = true;", true);
        }
    }
    protected void AsyncUpload1_FileUploaded(object sender, FileUploadedEventArgs e)
    {
        if ((totalBytes < MaxTotalBytes) && (e.File.ContentLength < MaxTotalBytes))
        {
            e.IsValid = true;
            totalBytes += e.File.ContentLength;
            IsRadAsyncValid = true;
        }
        else
        {
            e.IsValid = false;
            IsRadAsyncValid = false;
        }
    }
}